@@ -2,7 +2,8 @@ import pandas as pd
 import numpy as np 
 #-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 #                                                          INDICADOR RSI  OK TEST 1M,5M,15M,30M,1H,4H                                                                        #
-#  senial_rsi=rsi(datos,int(70),int(30),int(5),str("ema"),str("sma"),int(5),str("si"))
+#  senial_rsi=rsi(datos,int(70),int(30),int(14),str("ema"),str("sma"),int(14),str("si"))
+#  rsi(datos,venta_rsi,compra_rsi,rsi_periodo,ema_rsi,ema_mediamovil,ema_longitud,habilita_cruce)
 #----------------------------------------------------------------------------------------------------------------------------------------------------------------------------#
 def rsi(datos,venta_rsi,compra_rsi,rsi_periodo,ema_rsi,ema_mediamovil,ema_longitud,habilita_cruce):
     #Calcular el valor de RSI
@@ -72,7 +73,7 @@ def bb(datos,precio_actual,porcentaje_banda_arriba,porcentaje_banda_abajo, longi
     return senial
 #-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 #                                                        INDICADOR MEDIAS MOVILES   OK TEST 1M,5M,15M,30M,1H,4H                                                              #
-#    senial_ma=bb(datos,int(5),int(20),str("sma"))
+#      senial_ma=ma(datos,int(5),int(20),str("sma"))
 #----------------------------------------------------------------------------------------------------------------------------------------------------------------------------#
 def ma(datos, periodo, periodo1, ma_tipo):
     cierre=datos['close']
@@ -100,7 +101,7 @@ def ma(datos, periodo, periodo1, ma_tipo):
     return senial
 #-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 #                                                        INDICADOR BLOQUE DE ORDENES OK TEST 1M,5M,15M,30M,1H,4H                                                             #
-#  senial_bo=bo(datos,int(2),float(0.0))
+#  senial_bo=botgus.ob(datos,int(2),float(0.0))
 #----------------------------------------------------------------------------------------------------------------------------------------------------------------------------#
 def ob(datos, periodo, umbral):
     ob_period = periodo + 1
@@ -385,7 +386,7 @@ def pivot(df,tipo):
 #                                            INDICADOR DMI OK TEST 1M,5M,15M,30M,1H,4H                                                                                       #
 #  senial_dmi=dmi(datos,int(14),int(14))
 #----------------------------------------------------------------------------------------------------------------------------------------------------------------------------#
-def dmi(df,period,perioddi):
+def dmi(df,period,perioddi,conadx,umbral):
     df = df.copy()
     alphate = 1 / period
     adxperiodo = 1 / perioddi
@@ -410,12 +411,20 @@ def dmi(df,period,perioddi):
     df['ADX'] = df['DX'].ewm(alpha = alphate, adjust = False).mean()
     del df['DX'], df['ATR'], df['TR'], df['-DX'], df['+DX'], df['+DMI'], df['-DMI']
     adxx=df['ADX'].iloc[-1]
-    if float(adxx) > float(masx):
-        senial="comprar"
-    elif float(adxx) < float(masx):
-        senial="vender"
+    if conadx=="si":
+        if float(masx) > float(menosx) and float(adxx) > float(umbral):
+            senial="comprar"
+        elif float(masx) < float(menosx) and float(adxx) > float(umbral):
+            senial="vender"
+        else:
+            senial="ninguna" 
     else:
-        senial="ninguna" 
+        if float(masx) > float(menosx):
+            senial="comprar"
+        elif float(masx) < float(menosx):
+            senial="vender"
+        else:
+            senial="ninguna" 
 
     return senial
 #-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------
